@@ -1,6 +1,8 @@
 // -*- mode:C++; tab-width:8; c-basic-offset:8; indent-tabs-mode:nil -*-
-/* Blackjack - dialog.cpp
- * Copyright (C) 2003 William Jon McCann <mccann@jhu.edu>
+/* 
+ * Blackjack - dialog.cpp
+ *
+ * Copyright (C) 2003-2004 William Jon McCann <mccann@jhu.edu>
  *
  * This game is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,13 +20,11 @@
  * USA
  */
 
-#ifdef HAVE_CONFIG_H
 #include <config.h>
-#endif
 
 #include <stdlib.h>
-#include <dirent.h>
-#include <gnome.h>
+#include <glib/gi18n.h>
+#include <gtk/gtk.h>
 #include <games-card-selector.h>
 #include "blackjack.h"
 #include "menu.h"
@@ -35,40 +35,48 @@
 #include "game.h"
 #include "hand.h"
 
-#include <iostream>
 using namespace std;
 
-static GtkWidget *hint_dlg = NULL;
-static GtkWidget * deck_edit = NULL;
+static GtkWidget *hint_dlg  = NULL;
+static GtkWidget *deck_edit = NULL;
 
 gboolean
-get_insurance_choice ()
+get_insurance_choice (void)
 {
-        GtkWidget* dialog;
-        gchar* message;
-        gboolean choice = false;
+        GtkWidget  *dialog;
+        const char *message;
+        const char *secondary_message;
+        gboolean    choice = FALSE;
 
         message = _("Would you like insurance?");
+        secondary_message = _("Insurance is a side wager of 50%% of the original wager"
+                              " that the dealer has a natural 21 (aka blackjack) that is"
+                              " offered when the dealer's face up card is an ace. If the"
+                              " dealer has a natural 21 then the player is paid double.");
+        
+        dialog = gtk_message_dialog_new (GTK_WINDOW (toplevel_window),
+                                         GTK_DIALOG_MODAL,
+                                         GTK_MESSAGE_QUESTION,
+                                         GTK_BUTTONS_YES_NO,
+                                         message);
+
+        gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
+                                                  secondary_message);
 
-        dialog = gtk_message_dialog_new_with_markup (GTK_WINDOW (app),
-                                                     GTK_DIALOG_MODAL,
-                                                     GTK_MESSAGE_QUESTION,
-                                                     GTK_BUTTONS_YES_NO,
-                                                     "<span weight=\"bold\" size=\"larger\">%s</span>",
-                                                     message);
         gtk_container_set_border_width (GTK_CONTAINER (dialog), 6);
-
+        gtk_window_set_title (GTK_WINDOW (dialog), "");
         gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_NO);
 
         /* add a stock icon? */ 
         switch (gtk_dialog_run (GTK_DIALOG (dialog))) {
         case GTK_RESPONSE_YES: 
-                choice = true;
+                choice = TRUE;
                 break;
         default:
-                choice = false;
+                choice = FALSE;
                 break;
         }
+
         gtk_widget_destroy (dialog);
 
         return choice;
@@ -81,27 +89,35 @@ hint_destroy_callback (void)
 }
 
 void
-show_hint_dialog ()
+show_hint_dialog (void)
 {
-        gchar *gmessage;
+        char *message           = NULL;
+        char *secondary_message = NULL;
 
-        if (bj_game_is_first_hand ())
-                gmessage = g_strdup (_("Set your wager and click in the white outline to deal a new hand."));
-        else if (! bj_game_is_active ())
-                gmessage = g_strdup (_("Set your wager or click on the cards to deal a new hand."));
-        else
-                gmessage = bj_hand_get_best_option_string ();
+        if (bj_game_is_first_hand ()) {
+                message = g_strdup (_("Deal a new hand"));
+                secondary_message = g_strdup (_("Set your wager and click in the white outline to deal a new hand."));
+        } else if (! bj_game_is_active ()) {
+                message = g_strdup (_("Deal a new hand"));
+                secondary_message = g_strdup (_("Set your wager or click on the cards to deal a new hand."));
+        } else {
+                message = bj_hand_get_best_option_string (&secondary_message);
+        }
   
         if (hint_dlg)
                 gtk_widget_destroy (GTK_WIDGET (hint_dlg));
 
-        hint_dlg = gtk_message_dialog_new_with_markup (GTK_WINDOW (app),
-                                                       GTK_DIALOG_DESTROY_WITH_PARENT,
-                                                       GTK_MESSAGE_INFO,
-                                                       GTK_BUTTONS_OK,
-                                                       "<span weight=\"bold\" size=\"larger\">%s</span>",
-                                                       gmessage);
+        hint_dlg = gtk_message_dialog_new (GTK_WINDOW (toplevel_window),
+                                           GTK_DIALOG_DESTROY_WITH_PARENT,
+                                           GTK_MESSAGE_INFO,
+                                           GTK_BUTTONS_OK,
+                                           message);
+
+        gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (hint_dlg),
+                                                  secondary_message);
+
         gtk_container_set_border_width (GTK_CONTAINER (hint_dlg), 6);
+        gtk_window_set_title (GTK_WINDOW (hint_dlg), "");
 
         if (hint_dlg)
                 g_signal_connect (hint_dlg,
@@ -112,7 +128,8 @@ show_hint_dialog ()
 	gtk_dialog_run (GTK_DIALOG (hint_dlg));
 	gtk_widget_destroy (hint_dlg);
 
-        g_free (gmessage);
+        g_free (message);
+        g_free (secondary_message);
 }
 
 void 
@@ -141,6 +158,13 @@ quick_deal_toggle_cb (GtkToggleButton *w, gpointer data)
         bj_set_quick_deal (is_on);
 }
 
+void
+never_insurance_toggle_cb (GtkToggleButton *w, gpointer data)
+{
+        gboolean is_on = gtk_toggle_button_get_active (w);
+        bj_set_never_insurance (is_on);
+}
+
 enum {
         NAME_STRING,
         NDECKS_STRING,
@@ -183,7 +207,7 @@ reset_button_cb (GtkWidget *widget, gpointer data)
 }
 
 void
-show_preferences_dialog () 
+show_preferences_dialog (void) 
 {
         static GtkWidget* pref_dialog = NULL;
         GtkWidget *frame;
@@ -193,6 +217,7 @@ show_preferences_dialog ()
         GtkWidget *button;
         gboolean show_probabilities = false;
         gboolean quick_deal = false;
+        gboolean never_insurance = false;
         static GtkListStore* list;
         static GtkWidget* list_view;
         GtkWidget* scrolled_window;
@@ -203,15 +228,17 @@ show_preferences_dialog ()
 
         if (!pref_dialog) {
                 pref_dialog = gtk_dialog_new_with_buttons (_("Blackjack Preferences"),
-                                                           GTK_WINDOW (app), 
+                                                           GTK_WINDOW (toplevel_window), 
                                                            GTK_DIALOG_DESTROY_WITH_PARENT,
                                                            GTK_STOCK_CLOSE, 
                                                            GTK_RESPONSE_CLOSE,
                                                            NULL);
                 gtk_dialog_set_has_separator (GTK_DIALOG (pref_dialog), FALSE);
-                gtk_container_set_border_width (GTK_CONTAINER (pref_dialog), 6);
+                gtk_container_set_border_width (GTK_CONTAINER (pref_dialog), 5);
+                gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (pref_dialog)->vbox), 2);
                 
-                top_vbox = gtk_vbox_new (FALSE, 6);
+                top_vbox = gtk_vbox_new (FALSE, 18);
+                gtk_container_set_border_width (GTK_CONTAINER (top_vbox), 5);
                 gtk_container_add (GTK_CONTAINER (GTK_DIALOG (pref_dialog)->vbox),
                                    top_vbox);
                 
@@ -219,11 +246,11 @@ show_preferences_dialog ()
                 frame = games_frame_new (_("Game"));
                 vbox = gtk_vbox_new (FALSE, 6);
                 gtk_container_add (GTK_CONTAINER (frame), vbox);
-                gtk_box_pack_start_defaults (GTK_BOX (top_vbox), frame);
+                gtk_box_pack_start (GTK_BOX (top_vbox), frame, FALSE, FALSE, 0);
                 
                 // Show probabilities
                 show_probabilities = bj_get_show_probabilities ();
-                toggle = gtk_check_button_new_with_label (_("Display hand probabilities"));
+                toggle = gtk_check_button_new_with_mnemonic (_("_Display hand probabilities"));
                 gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (toggle),
                                               show_probabilities);
 
@@ -233,24 +260,32 @@ show_preferences_dialog ()
                 
                 // Quick deal
                 quick_deal = bj_get_quick_deal ();
-                toggle = gtk_check_button_new_with_label (_("Quick deals (no delay between each card)"));
+                toggle = gtk_check_button_new_with_mnemonic (_("_Quick deals (no delay between each card)"));
                 gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (toggle),
                                               quick_deal);
                 gtk_box_pack_start (GTK_BOX (vbox), toggle, FALSE, FALSE, 0);
                 g_signal_connect (toggle, "toggled",
                                   G_CALLBACK (quick_deal_toggle_cb), NULL);
-                
-                button = gtk_button_new_with_label (_("Reset balance"));
+
+                // No insurance
+                never_insurance = bj_get_never_insurance ();
+                toggle = gtk_check_button_new_with_mnemonic (_("_Never take insurance"));
+                gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (toggle),
+                                              never_insurance);
+                gtk_box_pack_start (GTK_BOX (vbox), toggle, FALSE, FALSE, 0);
+                g_signal_connect (toggle, "toggled",
+                                  G_CALLBACK (never_insurance_toggle_cb), NULL); 
+               
+                button = gtk_button_new_with_mnemonic (_("_Reset Balance"));
                 gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
                 g_signal_connect (button, "clicked",
-                                  G_CALLBACK (reset_button_cb), NULL);
-                
+                                  G_CALLBACK (reset_button_cb), NULL);               
                 
                 // Rules Tab
                 frame = games_frame_new (_("Rules"));
                 vbox = gtk_vbox_new (FALSE, 6);
                 gtk_container_add (GTK_CONTAINER (frame), vbox);
-                gtk_box_pack_start_defaults (GTK_BOX (top_vbox), frame);
+                gtk_box_pack_start (GTK_BOX (top_vbox), frame, TRUE, TRUE, 0);
 
                 list = gtk_list_store_new (13, 
                                            G_TYPE_STRING,  // Name
@@ -343,8 +378,7 @@ show_preferences_dialog ()
                                                 GTK_POLICY_AUTOMATIC,
                                                 GTK_POLICY_AUTOMATIC);
                 
-                gtk_box_pack_end (GTK_BOX (vbox), scrolled_window, TRUE, TRUE,
-                                  GNOME_PAD_SMALL );
+                gtk_box_pack_end (GTK_BOX (vbox), scrolled_window, TRUE, TRUE, 0);
                 
                 g_signal_connect (select, "changed", 
                                   G_CALLBACK (select_rule_cb), (gpointer) pref_dialog);
@@ -385,8 +419,8 @@ show_preferences_dialog ()
                 g_free (current_rule);
                 
                 // Cards Tab
-                deck_edit = games_card_selector_new (bj_get_card_style ());
-                gtk_box_pack_start_defaults (GTK_BOX (top_vbox), deck_edit);
+                deck_edit = games_card_selector_new (TRUE, bj_get_card_style ());
+                gtk_box_pack_start (GTK_BOX (top_vbox), deck_edit, FALSE, FALSE, 0);
 
                 g_signal_connect (deck_edit, "changed",
                                   G_CALLBACK (card_deck_options_changed), NULL);
