@@ -28,11 +28,11 @@ if (sys.modules.has_key('glchess') and
     UNFINISHED_FILE  = os.path.join(HISTORY_DIR, 'unfinished')
     LOCAL_AI_CONFIG  = os.path.join(DATA_DIR, 'ai.xml')
 else:
-    APP_DATA_DIR     = os.path.join('/home/jclinton/gnome-games', 'glchess', 'data')
-    ICON_DIR         = os.path.join('/home/jclinton/gnome-games', 'glchess', 'textures')
-    TEXTURE_DIR      = os.path.join('/home/jclinton/gnome-games', 'glchess', 'textures')
-    GLADE_DIR        = os.path.join('/home/jclinton/gnome-games', 'glchess', 'glade')
-    BASE_DIR         = os.path.join('/home/jclinton/gnome-games', 'glchess', 'data')
+    APP_DATA_DIR     = os.path.join('/home/thomas/svnbranch/gnome-games', 'glchess', 'data')
+    ICON_DIR         = os.path.join('/home/thomas/svnbranch/gnome-games', 'glchess', 'textures')
+    TEXTURE_DIR      = os.path.join('/home/thomas/svnbranch/gnome-games', 'glchess', 'textures')
+    GLADE_DIR        = os.path.join('/home/thomas/svnbranch/gnome-games', 'glchess', 'glade')
+    BASE_DIR         = os.path.join('/home/thomas/svnbranch/gnome-games', 'glchess', 'data')
     LOCALEDIR        = os.path.join(APP_DATA_DIR, 'locale')
     DATA_DIR         = os.path.expanduser('~/.gnome2/glchess/')
     LOG_DIR          = os.path.join(DATA_DIR, 'logs')
@@ -50,7 +50,7 @@ import gtk.glade
 gtk.glade.bindtextdomain(DOMAIN, LOCALEDIR)
 gtk.glade.textdomain(DOMAIN)
 
-VERSION   = "2.22.1"
+VERSION   = "2.22.1.1"
 APPNAME   = _("glChess")
 ICON_NAME = 'gnome-glchess'
 
